
<!--

#################################################
### THIS FILE WAS AUTOGENERATED! DO NOT EDIT! ###
#################################################
# file to edit: index.ipynb
# command to build the docs after a change: nbdev_build_docs

-->

# wide_and_deep

> Use wide and deep model to do multi-classification tasks.


This model is developed for the debt-collection robot. The robot calls customers within several topics. However, the human agents make different performances in these topics based on the payback money. If we find in a subtopic, human agents make a better performance, we will analyze the conversations they make with customers and write specific strategies for robots.

We collect the conversation between robot and customers and transform them into word2vector using a pre-trained model, use a bidirectional LSTM framework to extract features and use the wide and deep model to do the multi-label classification for higher accuracy (88-93%).

## Install

`pip install wide_and_deep`

## How to use

See demo https://jiaxiangbu.github.io/user_communication_classificationEX/
